Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(42)

Unified Diff: chrome/browser/chromeos/login/lock/screen_locker.h

Issue 2015413002: Enable the PIN keyboard on the lockscreen. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@lkgr
Patch Set: Address comments Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/chromeos/login/lock/screen_locker.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chromeos/login/lock/screen_locker.h
diff --git a/chrome/browser/chromeos/login/lock/screen_locker.h b/chrome/browser/chromeos/login/lock/screen_locker.h
index c66cc0c8a862bea59780ef23d72a9461e1d6ccb2..856162047e922dc4e36fb28e303bbc31459e5e23 100644
--- a/chrome/browser/chromeos/login/lock/screen_locker.h
+++ b/chrome/browser/chromeos/login/lock/screen_locker.h
@@ -65,6 +65,10 @@ class ScreenLocker : public AuthStatusConsumer {
void OnAuthFailure(const chromeos::AuthFailure& error) override;
void OnAuthSuccess(const UserContext& user_context) override;
+ // Called when an account password (not PIN/quick unlock) has been used to
+ // unlock the device.
+ void OnPasswordAuthSuccess(const UserContext& user_context);
+
// Does actual unlocking once authentication is successful and all blocking
// animations are done.
void UnlockOnLoginSuccess();
@@ -142,11 +146,11 @@ class ScreenLocker : public AuthStatusConsumer {
// Called when screen locker is safe to delete.
static void ScheduleDeletion();
- // Returns true if |username| is found among logged in users.
- bool IsUserLoggedIn(const std::string& username);
+ // Returns true if |account_id| is found among logged in users.
+ bool IsUserLoggedIn(const AccountId& account_id) const;
// Looks up user in unlock user list.
- const user_manager::User* FindUnlockUser(const std::string& user_id);
+ const user_manager::User* FindUnlockUser(const AccountId& account_id);
// ScreenLockerDelegate instance in use.
std::unique_ptr<ScreenLockerDelegate> delegate_;
« no previous file with comments | « no previous file | chrome/browser/chromeos/login/lock/screen_locker.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698